.image {
  overflow: hidden;
  width: auto;
  max-width: 100%;
  position: relative;
  padding-top: 0px;
  float: none;
  clear: both; }
  .image > div {
    position: relative;
    height: auto;
    overflow: hidden; }
    .image > div > img {
      display: block;
      width: 100%;
      position: absolute;
      top: 0;
      left: 0;
      height: 100%; }

@-ms-viewport {
  width: device-width; }
.sc-hero {
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-direction: normal;
  -webkit-box-orient: vertical;
  -webkit-flex-direction: column;
  -moz-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  background: #212121;
  color: white;
  margin: auto;
  margin-bottom: 3em;
  max-width: 1425px;
  position: relative;
  width: 100%; }
  .sc-hero .hero-img {
    width: 100%; }
    .sc-hero .hero-img .image > div {
      padding-bottom: 56.25%; }
  .sc-hero .sc-label {
    background: rgba(33, 33, 33, 0.8);
    color: white;
    display: none;
    font-size: 1.15em;
    left: 0;
    padding: 10px 30px;
    position: absolute;
    text-transform: uppercase;
    top: 60px; }
  .sc-hero .billboard {
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-flex;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-direction: normal;
    -webkit-box-orient: vertical;
    -webkit-flex-direction: column;
    -moz-flex-direction: column;
    -ms-flex-direction: column;
    flex-direction: column;
    -webkit-box-align: center;
    -ms-flex-align: center;
    -webkit-align-items: center;
    -moz-align-items: center;
    align-items: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    -webkit-justify-content: center;
    -moz-justify-content: center;
    justify-content: center;
    padding: 1em;
    text-align: center; }
  .sc-hero .sponsor {
    display: -webkit-box;
    display: -webkit-flex;
    display: -moz-flex;
    display: -ms-flexbox;
    display: flex;
    text-transform: uppercase; }
    .sc-hero .sponsor figure {
      margin: auto;
      max-width: 100px;
      padding-top: 20px;
      width: 100%; }
      .sc-hero .sponsor figure img {
        display: block;
        position: relative;
        width: 100%; }
  .sc-hero.full-bleed .billboard {
    width: 100%; }

.sc-grid {
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-flow: row wrap;
  -moz-flex-flow: row wrap;
  -ms-flex-flow: row wrap;
  flex-flow: row wrap;
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  -webkit-justify-content: space-between;
  -moz-justify-content: space-between;
  justify-content: space-between;
  margin: 3em auto;
  max-width: 970px;
  padding: 0;
  width: 95%; }
  .sc-grid.two-up .sc-item {
    width: 100%; }
  .sc-grid.two-up .sc-item.large {
    width: 100%; }
  .sc-grid .dfp {
    -webkit-transition: width 0.5s, height 0.5s, transform 0.5s;
    -moz-transition: width 0.5s, height 0.5s, transform 0.5s;
    -ms-transition: width 0.5s, height 0.5s, transform 0.5s;
    -o-transition: width 0.5s, height 0.5s, transform 0.5s;
    margin: auto;
    padding-bottom: 3em;
    display: table;
    position: relative;
    z-index: 1; }

.sc-item {
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-direction: normal;
  -webkit-box-orient: vertical;
  -webkit-flex-direction: column;
  -moz-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-align: center;
  -ms-flex-align: center;
  -webkit-align-items: center;
  -moz-align-items: center;
  align-items: center;
  background: #eaeaea;
  margin-bottom: 3em;
  text-align: center; }
  .sc-item .thumb {
    width: 100%; }
    .sc-item .thumb .image > div {
      padding-bottom: 56.25%; }
  .sc-item .meta {
    padding: 10%; }
    .sc-item .meta h2 {
      font-size: 1.3em; }
    .sc-item .meta .feature-type {
      color: black;
      text-transform: uppercase; }
    .sc-item .meta .pub {
      color: #7a8781;
      font-size: .75em; }
  .sc-item a {
    color: black;
    width: 100%; }
    .sc-item a:hover {
      color: black; }
  .sc-item.large {
    -webkit-box-direction: normal;
    -webkit-box-orient: horizontal;
    -webkit-flex-direction: row;
    -moz-flex-direction: row;
    -ms-flex-direction: row;
    flex-direction: row;
    background: transparent;
    position: relative; }
    .sc-item.large a {
      display: -webkit-box;
      display: -webkit-flex;
      display: -moz-flex;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-direction: normal;
      -webkit-box-orient: vertical;
      -webkit-flex-direction: column;
      -moz-flex-direction: column;
      -ms-flex-direction: column;
      flex-direction: column; }
    .sc-item.large .thumb {
      width: 100%; }
    .sc-item.large .meta {
      display: -webkit-box;
      display: -webkit-flex;
      display: -moz-flex;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-direction: normal;
      -webkit-box-orient: vertical;
      -webkit-flex-direction: column;
      -moz-flex-direction: column;
      -ms-flex-direction: column;
      flex-direction: column;
      -webkit-box-align: center;
      -ms-flex-align: center;
      -webkit-align-items: center;
      -moz-align-items: center;
      align-items: center;
      -webkit-box-pack: center;
      -ms-flex-pack: center;
      -webkit-justify-content: center;
      -moz-justify-content: center;
      justify-content: center;
      background: #eaeaea;
      color: black;
      position: relative;
      width: 100%; }

@media all and (min-width: 600px) {
  .sc-grid.two-up .sc-item {
    width: 48%; }
  .sc-grid.two-up .sc-item.large {
    width: 100%; }

  .sc-item.large {
    -webkit-box-direction: normal;
    -webkit-box-orient: horizontal;
    -webkit-flex-direction: row;
    -moz-flex-direction: row;
    -ms-flex-direction: row;
    flex-direction: row;
    background: transparent;
    position: relative; }
    .sc-item.large a {
      display: -webkit-box;
      display: -webkit-flex;
      display: -moz-flex;
      display: -ms-flexbox;
      display: flex; }
    .sc-item.large .thumb {
      width: 70%; }
    .sc-item.large .meta {
      display: -webkit-box;
      display: -webkit-flex;
      display: -moz-flex;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-direction: normal;
      -webkit-box-orient: vertical;
      -webkit-flex-direction: column;
      -moz-flex-direction: column;
      -ms-flex-direction: column;
      flex-direction: column;
      -webkit-box-align: center;
      -ms-flex-align: center;
      -webkit-align-items: center;
      -moz-align-items: center;
      align-items: center;
      -webkit-box-pack: center;
      -ms-flex-pack: center;
      -webkit-justify-content: center;
      -moz-justify-content: center;
      justify-content: center;
      background: rgba(0, 0, 0, 0.8);
      bottom: 15%;
      color: white;
      max-width: 400px;
      padding: 5%;
      position: absolute;
      right: 0;
      top: 15%; }

  .sc-hero .sc-label {
    display: inline-block; } }
@media all and (min-width: 1000px) {
  .sc-hero {
    -webkit-box-direction: normal;
    -webkit-box-orient: horizontal;
    -webkit-flex-direction: row;
    -moz-flex-direction: row;
    -ms-flex-direction: row;
    flex-direction: row; }
    .sc-hero .hero-img {
      width: 65%; }
    .sc-hero .billboard {
      padding: 1.5em;
      width: 35%; } }
